--[=[
--	Module Name: GPS
--	Purpose: To display the Zone and Co-ordinates of the players current location
--	Version: 0.1
--]=]

local addon, ns = ...
local C = ns.shared.color
local func = ns.shared
local L = ns.L

local tooltip = nil

-- Update frequency 1 second.
local UPDATEPERIOD = 2

local GPSEvents = {
	"PLAYER_LOGIN",
	"ZONE_CHANGED",
	"ZONE_CHANGED_INDOORS",
	"ZONE_CHANGED_NEW_AREA",
	"PLAYER_ENTERING_WORLD",
	"ADDON_LOADED"
}

local gpsLoc = {
	zone = " ",
	color = "white",
	pvp = "contested",
}
local f = CreateFrame("frame")

-- Function to get the GPS co-ordinates
local function getCoordinates()
	local location = ""
	local x, y = GetPlayerMapPosition("player")

	if x ~= 0 and y ~= 0 then
		location = string.format("%.1f, %.1f", x * 100, y * 100)
	end

	return location
end

-- Function to get the current Zone or subzone
local function getZone()
	local subZone = GetSubZoneText() or ""
	local zone = GetRealZoneText() or ""

	if subZone == nil  or subZone == "" then
		return zone
	else
		return subZone
	end
end

-- Function ot return the pvp zone information and the related color to color text.
local function getPVP()
	local p, _, f = GetZonePVPInfo()
	local color = "white"

	if p == "combat" or p == "arena" or p == "hostile" then
		color = "red"
	elseif p == "contested" or p == nil then
		color = "dkyellow"
		p = "contested"
	elseif p == "friendly" then
		color = "dkgreen"
	elseif p == "sanctuary" then
		color = "ltblue"
	end

	return p, color
end

-- Event Handler
local function gps_OnEvent(self, event)
	if (event == "PLAYER_LOGIN") or (event == "ZONE_CHANGED") or (event == "ZONE_CHANGED_INDOORS") or (event == "ZONE_CHANGED_NEW_AREA") or (event == "PLAYER_ENTERING_WORLD") or (event == "ADDON_LOADED") then
		local dataobj = self.obj or LibStub:GetLibrary("LibDataBroker-1.1"):GetDataObjectByName(L["GPS"])
		gpsLoc.zone = getZone()
		gpsLoc["pvp"], gpsLoc["color"] = getPVP()
		dataobj.text = C[gpsLoc.color](string.format("%s (%s)", gpsLoc.zone, getCoordinates()))	
	end
end

-- Function to Populate the GPS Tooltip
local function drawGPSTip()
	local pvp, color = getPVP()
        pvp = gsub(pvp,"^%l", string.upper)

	tooltip:AddHeader(C.dkyellow(L["GPS"]))
	tooltip:AddLine(" ")

	tooltip:AddLine(C.ltblue(L["Location Information"]))
	tooltip:AddSeparator()
	tooltip:AddLine(C.ltyellow(L["Zone"] .. ":"), GetRealZoneText())
	tooltip:AddLine(C.ltyellow(L["Sub-Zone"] .. ":"), GetSubZoneText())
	tooltip:AddLine(C.ltyellow(L["PVP Flag"] .. ":"), C[color](pvp))
	tooltip:AddLine(C.ltyellow(L["Co-ordinates"] .. ":"), getCoordinates())
	tooltip:AddLine(" ")

	tooltip:AddLine(C.ltblue(L["Home"]))
	tooltip:AddSeparator()
	tooltip:AddLine(C.ltyellow(L["Inn"]), GetBindLocation())
	tooltip:AddLine(" ")
	
	local line, column = tooltip:AddLine()
	tooltip:SetCell(line, 1, C.dkgreen(L["Hint: Click to open the World Map."]), nil, nil, 2)	
end

local gps_init = function(obj)
	if not obj then return end

	obj = obj.obj or LibStub:GetLibrary("LibDataBroker-1.1"):GetDataObjectByName(L["GPS"])

	obj.OnLeave = function ()
		if tooltip then
			LibQTip:Release(tooltip)
			tooltip = nil
		end
	end

	obj.OnEnter = function(self)
		tooltip = LibQTip:Acquire("GPSTT", 2, LEFT, RIGHT) 
		drawGPSTip()
		func.createTooltip(self,tooltip)
	end
end


local function gps_OnUpdate(self)
	local dataobj = self.obj or LibStub:GetLibrary("LibDataBroker-1.1"):GetDataObjectByName(L["GPS"])
	dataobj.text = C[gpsLoc.color](string.format("%s (%s)", gpsLoc.zone, getCoordinates()))
end

local gps_onclick = function()
	if GUILockDown == nil then 
		ToggleFrame(WorldMapFrame)
	elseif GUILockDown == 1 then 
		return 
	end
end

Broker_Everything:Register(L["GPS"],
	"Interface\\Addons\\Broker_Everything\\media\\gps",--GetItemIcon(11105),
	gps_init,
	gps_OnEvent,
	GPSEvents,
	gps_onclick,
	0,
	gps_OnUpdate,
	UPDATEPERIOD)